pub enum WindowInstanceState {
Building,
Loading,
Loaded {
has_view: bool,
},
Closed,
}Expand description
Represents stages of a window instance lifetime.
Variants
Building
The new window closure is running.
The WINDOWS.vars is available.
Loading
Some WindowLoadingHandle are still held.
The WINDOWS.widget_tree is available, the window is awaiting load to show.
Loaded
Window is fully loaded or load handles have timeout.
Fields
Closed
Window content and view has deinited and dropped.
The WindowVars::instance_state variable will not update again.
Implementations