pub struct FrameImageReadyArgs {
pub timestamp: DInstant,
pub window_id: WindowId,
pub frame_id: FrameId,
pub frame_image: WeakVarEq<ImageEntry>,
pub propagation: EventPropagationHandle,
}Expand description
FRAME_IMAGE_READY_EVENT args.
Fields
timestamp: DInstantInstant the event happened.
window_id: WindowIdWindow ID.
frame_id: FrameIdFrame that finished rendering.
This is probably the ID of frame pixels if they are requested immediately.
frame_image: WeakVarEq<ImageEntry>The frame pixels.
See WindowVars::frame_capture_mode for more details. The image reference will hold only for the hooks, you must upgrade it
to keep it, this is done to avoid retaining the image in the last event.
propagation: EventPropagationHandlePropagation handle associated with this event instance.
Cloned arguments share the same handle, some arguments may also share the handle of another event if they share the same cause.
Implementations