pub struct ImeArgs {
pub timestamp: DInstant,
pub target: WidgetPath,
pub txt: Txt,
pub preview_caret: Option<(usize, usize)>,
pub propagation: EventPropagationHandle,
}Expand description
Arguments for IME_EVENT.
Fields
timestamp: DInstantInstant the event happened.
target: WidgetPathThe enabled text input widget.
txt: TxtThe text, preview or actual insert.
preview_caret: Option<(usize, usize)>Caret/selection within the txt when it is preview.
The indexes are in char byte offsets and indicate where the caret or selection must be placed on
the inserted or preview txt, if not set the position is at the end of the insert.
If this is None the text must commit.
propagation: EventPropagationHandlePropagation handle associated with this event instance.
Cloned arguments share the same handle, some arguments may also share the handle of another event if they share the same cause.
Implementations
Sourceimpl ImeArgs
impl ImeArgs
Sourceimpl ImeArgs
impl ImeArgs
Sourcepub fn commit(&self) -> bool
pub fn commit(&self) -> bool
If the text must be actually inserted.
If true the txt must be actually inserted at the last non-preview caret/selection, the caret then must be moved to
after the inserted text.
If false the widget must visually adjust the text and caret to look as if the input has committed, but the
actual text must not be altered, and if the txt is empty the previous caret/selection must be restored.
Usually the preview text is rendered with an underline effect, otherwise it has the same appearance as the
committed text.