pub struct MonitorsChangedArgs {
pub timestamp: DInstant,
pub removed: Vec<MonitorId>,
pub added: Vec<MonitorId>,
pub modified: Vec<MonitorId>,
pub propagation: EventPropagationHandle,
}Expand description
MONITORS_CHANGED_EVENT args.
Fields
timestamp: DInstantInstant the event happened.
removed: Vec<MonitorId>Removed monitors.
added: Vec<MonitorId>Added monitors.
Use the MONITORS service to get metadata about the added monitors.
modified: Vec<MonitorId>Modified monitors.
The monitor metadata is tracked using variables that are now flagged new.
propagation: EventPropagationHandlePropagation handle associated with this event instance.
Cloned arguments share the same handle, some arguments may also share the handle of another event if they share the same cause.
Implementations