pub struct OpenNestedHandlerArgs { /* private fields */ }Expand description
Arguments for the WINDOWS_EXTENSIONS.register_open_nested_handler handler.
Implementations
Sourceimpl OpenNestedHandlerArgs
impl OpenNestedHandlerArgs
Sourcepub fn nest(&mut self) -> NestedWindowNode
pub fn nest(&mut self) -> NestedWindowNode
Instantiate a node that layouts and renders the window content.
Calling this will stop the normal window chrome from opening, the caller is responsible for inserting the node into the main window layout.
Note that the window will notify open like normal, but it will only be visible on this node.