pub struct WINDOWS_DIALOG;Expand description
Windows dialog service integration.
Implementations
Sourceimpl WINDOWS_DIALOG
impl WINDOWS_DIALOG
Sourcepub fn native_message_dialog(
&self,
window_id: impl Into<WindowId>,
dialog: MsgDialog,
) -> ResponseVar<MsgDialogResponse>
pub fn native_message_dialog( &self, window_id: impl Into<WindowId>, dialog: MsgDialog, ) -> ResponseVar<MsgDialogResponse>
Show a native message dialog for the window.
The dialog can be modal in the view-process, in the app-process it is always async, the response var will update once when the user responds to the dialog.
Consider using the DIALOG service instead of the method directly.
Sourcepub fn native_file_dialog(
&self,
window_id: impl Into<WindowId>,
dialog: FileDialog,
) -> ResponseVar<FileDialogResponse>
pub fn native_file_dialog( &self, window_id: impl Into<WindowId>, dialog: FileDialog, ) -> ResponseVar<FileDialogResponse>
Show a native file dialog for the window.
The dialog can be modal in the view-process, in the app-process it is always async, the response var will update once when the user responds to the dialog.
Consider using the DIALOG service instead of the method directly.
Sourcepub fn available_operations(&self) -> WindowCapability
pub fn available_operations(&self) -> WindowCapability
Window operations supported by the current view-process instance for headed windows.
Not all window operations may be available, depending on the operating system and build. When an operation is not available an error is logged and otherwise ignored.