pub struct WINDOWS_FOCUS;Expand description
Windows focus service integration.
The FOCUS uses this.
Implementations
Sourceimpl WINDOWS_FOCUS
impl WINDOWS_FOCUS
Sourcepub fn hook_focus_service(&self, focused: Var<Option<InteractionPath>>)
pub fn hook_focus_service(&self, focused: Var<Option<InteractionPath>>)
Setup a var that is controlled by the focus service and tracks the focused widget.
This must be called by the focus implementation only.