pub struct WindowCloseArgs {
pub timestamp: DInstant,
pub windows: IdSet<WindowId>,
pub propagation: EventPropagationHandle,
}Expand description
WINDOW_CLOSE_EVENT args.
Fields
timestamp: DInstantInstant the event happened.
windows: IdSet<WindowId>IDs of windows that have closed.
This is at least one window, is multiple if the close operation was requested as group.
propagation: EventPropagationHandlePropagation handle associated with this event instance.
Cloned arguments share the same handle, some arguments may also share the handle of another event if they share the same cause.
Implementations