pub struct WindowFocusChangedArgs {
pub timestamp: DInstant,
pub prev_focus: Option<WindowId>,
pub new_focus: Option<WindowId>,
pub closed: bool,
pub propagation: EventPropagationHandle,
}Expand description
Fields
timestamp: DInstantInstant the event happened.
prev_focus: Option<WindowId>Previously focused window.
new_focus: Option<WindowId>Newly focused window.
closed: boolIf the focus changed because the previously focused window closed.
propagation: EventPropagationHandlePropagation handle associated with this event instance.
Cloned arguments share the same handle, some arguments may also share the handle of another event if they share the same cause.
Implementations
Sourceimpl WindowFocusChangedArgs
impl WindowFocusChangedArgs