pub struct WindowOpenArgs {
pub timestamp: DInstant,
pub window_id: WindowId,
pub propagation: EventPropagationHandle,
}Expand description
WINDOW_OPEN_EVENT args.
Fields
timestamp: DInstantInstant the event happened.
window_id: WindowIdId of window that has opened.
propagation: EventPropagationHandlePropagation handle associated with this event instance.
Cloned arguments share the same handle, some arguments may also share the handle of another event if they share the same cause.
Implementations