NestedWindowWidgetInfoExt

Trait NestedWindowWidgetInfoExt 

pub trait NestedWindowWidgetInfoExt {
    // Required method
    fn nested_window(&self) -> Option<WindowId>;

    // Provided method
    fn nested_window_tree(&self) -> Option<WidgetInfoTree> { ... }
}
Extension methods for widget info about a node that hosts a nested window.

Required Methods

fn nested_window(&self) -> Option<WindowId>

Gets the hosted window ID if the widget hosts a nested window.

Provided Methods

fn nested_window_tree(&self) -> Option<WidgetInfoTree>

Gets the hosted window info tree if the widget hosts a nested window that is open.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl NestedWindowWidgetInfoExt for WidgetInfo

Implementors